Kerapu
======

Een implementatie van de Grouper in Python.

 
| Social                                                                                                                     |  Docs                                                                                      | Legal                                                                   | Release                                        | Tests                                                                                   | Code                                                                                                   |
 
| .. image:: https://badges.gitter.im/SetBased/py-kerapu.svg                                                                 | .. image:: https://readthedocs.org/projects/kerapu/badge/?version=latest                   | .. image:: https://img.shields.io/github/license/setbased/py-kerapu.svg | .. image:: https://badge.fury.io/py/Kerapu.svg | .. image:: https://travis-ci.org/SetBased/py-kerapu.svg?branch=master                   | .. image:: https://scrutinizer-ci.com/g/SetBased/py-kerapu/badges/quality-score.png?b=master           |
|   :target: https://gitter.im/SetBased/py-kerapu?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge  |    :target: https://kerapu.readthedocs.io/nl/latest/?badge=latest                          |   :target: https://opensource.org/licenses/MIT                          |   :target: https://badge.fury.io/py/Kerapu     |   :target: https://travis-ci.org/SetBased/py-kerapu                                     |   :target: https://scrutinizer-ci.com/g/SetBased/py-kerapu/?branch=master                              |
|                                                                                                                            |    :alt: Documentation Status                                                              |                                                                         |                                                | .. image:: https://scrutinizer-ci.com/g/SetBased/py-kerapu/badges/coverage.png?b=master |                                                                                                        |
|                                                                                                                            |                                                                                            |                                                                         |                                                |   :target: https://scrutinizer-ci.com/g/SetBased/py-kerapu/?branch=master               |                                                                                                        |
 

Documentatie
============

De documentatie van Kerapu is beschikbaar op `Read the Docs`_.

.. _`Read the Docs`: https://kerapu.readthedocs.io

Ondersteuning en bijdragen
==========================

Ondersteuning is beschikbaar via GitHub tickets, Gitter_ en email: support@setbased.nl.

Bijdragen zijn uiteraard welkom, we werken volgens de GitHub Flow, zie de handleiding_ voor het maken een pull request.

.. _Gitter: https://gitter.im/SetBased/py-kerapu
.. _handleiding: https://guides.github.com/introduction/flow/

Licentie
========

Dit project is gelicentieerd onder de MIT-licentie.
